@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = 'v0.2.6'; # VERSION
+our $VERSION = 'v0.2.7'; # VERSION
 
 use Moose::Role;
 with qw(
@@ -41,6 +41,20 @@ has avs_code_raw => (
 		. 'Returned only if a value is returned by the processor.',
 );
 
+has cv_code => (
+	required  => 0,
+	predicate => 'has_cv_code',
+	is        => 'ro',
+	isa       => Varchar[1],
+);
+
+has cv_code_raw => (
+	required  => 0,
+	predicate => 'has_cv_code_raw',
+	is        => 'ro',
+	isa       => Varchar[10],
+);
+
 
 1;
 
@@ -55,7 +69,7 @@ Business::CyberSource::Response::Role::Authorization - CyberSource Authorization
 
 =head1 VERSION
 
-version v0.2.6
+version v0.2.7
 
 =head1 BUGS
 
